@@ -13,6 +13,7 @@ from tagbackup.lib import (
 
 
 @click.command()
+@click.argument('organization', nargs=1)
 @click.argument("tags", nargs=-1)
 @click.option(
     "--filename",
@@ -23,7 +24,7 @@ from tagbackup.lib import (
 @click.option(
     "--overwrite", is_flag=True, help="Overwrite existing file (if it exists)"
 )
-def pull(tags, filename, overwrite):
+def pull(organization, tags, filename, overwrite):
     """
     Learn more at https://tagbackup.com/docs/client/pull
     """
@@ -49,6 +50,7 @@ def pull(tags, filename, overwrite):
         "v1/pull",
         device_id,
         {
+            "organization": organization,
             "tags": tags_to_csv(list(set(tags))),
         },
         True,
